import { DynamicReference } from './DynamicReference';
import type { ErrorReporter } from './ErrorReporter';
export type ToString = {
    toString(): string;
};
interface CubeDefinition {
    name: string;
    extends?: (...args: Array<unknown>) => {
        __cubeName: string;
    };
    sql?: string | (() => string);
    sql_table?: string | (() => string);
    sqlTable?: string | (() => string);
    measures?: Record<string, any>;
    dimensions?: Record<string, any>;
    segments?: Record<string, any>;
    hierarchies?: Record<string, any>;
    preAggregations?: Record<string, any>;
    pre_aggregations?: Record<string, any>;
    joins?: Record<string, any>;
    accessPolicy?: any[];
    folders?: any[];
    includes?: any;
    excludes?: any;
    cubes?: any;
    isView?: boolean;
    isSplitView?: boolean;
    includedMembers?: any[];
}
interface CubeDefinitionExtended extends CubeDefinition {
    allDefinitions: (type: string) => Record<string, any>;
    rawFolders: () => any[];
    rawCubes: () => any[];
}
interface SplitViews {
    [key: string]: any;
}
export declare const CONTEXT_SYMBOLS: {
    SECURITY_CONTEXT: string;
    security_context: string;
    securityContext: string;
    FILTER_PARAMS: string;
    FILTER_GROUP: string;
    SQL_UTILS: string;
};
export declare const CURRENT_CUBE_CONSTANTS: string[];
export declare class CubeSymbols {
    symbols: Record<string | symbol, any>;
    private builtCubes;
    private cubeDefinitions;
    private funcArgumentsValues;
    cubeList: any[];
    private readonly evaluateViews;
    private resolveSymbolsCallContext;
    constructor(evaluateViews?: boolean);
    compile(cubes: CubeDefinition[], errorReporter: ErrorReporter): void;
    getCubeDefinition(cubeName: string): CubeDefinitionExtended;
    createCube(cubeDefinition: CubeDefinition): CubeDefinitionExtended;
    protected transform(cubeName: string, errorReporter: ErrorReporter, splitViews: SplitViews): {
        cubeName: () => string;
        cubeObj: () => CubeDefinitionExtended;
    };
    private camelCaseTypes;
    protected transformPreAggregations(preAggregations: Object): void;
    protected transformPreAggregationIndexes(indexes: Object): void;
    protected prepareIncludes(cube: CubeDefinitionExtended, errorReporter: ErrorReporter, splitViews: SplitViews): void;
    protected applyIncludeMembers(includeMembers: any[], cube: CubeDefinition, type: string, errorReporter: ErrorReporter): void;
    protected membersFromCubes(parentCube: CubeDefinition, cubes: any[], type: string, errorReporter: ErrorReporter, splitViews: SplitViews, memberSets: any): any[];
    protected diffByMember(includes: any[], excludes: any[]): any[];
    protected getResolvedMember(type: string, cubeName: string, memberName: string): any;
    protected generateIncludeMembers(members: any[], cubeName: string, type: string): any[][];
    /**
     * This method is mainly used for evaluating RLS conditions and filters.
     * It allows referencing security_context (lowercase) in dynamic conditions or filter values.
     *
     * It currently does not support async calls because inner resolveSymbol and
     * resolveSymbolsCall are sync. Async support may be added later with deeper
     * refactoring.
     */
    protected evaluateContextFunction(cube: any, contextFn: any, context?: any): unknown;
    protected evaluateReferences<T extends ToString | Array<ToString>>(cube: string | null, referencesFn: (...args: Array<unknown>) => T, options?: {
        collectJoinHints?: boolean;
        originalSorting?: boolean;
    }): T extends Array<ToString> ? Array<string> : T extends ToString ? string : string | Array<string>;
    pathFromArray(array: string[]): string;
    /**
     * Split join path to member to join hint and member path: `A.B.C.D.E.dim` => `[A, B, C, D, E]` + `E.dim`
     * @param path
     */
    static joinHintFromPath(path: string): {
        path: string;
        joinHint: Array<string>;
    };
    protected resolveSymbolsCall<T>(func: (...args: Array<unknown>) => T | DynamicReference<T>, nameResolver: (id: string) => unknown, context?: unknown): T;
    protected withSymbolsCallContext(func: any, context: any): any;
    protected funcArguments(func: any): string[];
    protected joinHints(): any;
    protected resolveSymbolsCallDeps(cubeName: any, sql: any): any[];
    protected depsContextSymbols(): {
        filterParams: {};
        filterGroup: (...filterParamArgs: any[]) => string;
        securityContext: object;
        sqlUtils: {
            convertTz: (f: any) => any;
        };
    };
    protected filtersProxyDep(): {};
    protected filterGroupFunctionDep(): (...filterParamArgs: any[]) => string;
    resolveSymbol(cubeName: any, name: any): any;
    protected cubeReferenceProxy(cubeName: any, joinHints?: any[], refProperty?: any): any;
    /**
     * Tries to resolve Granularity object.
     * For predefined granularity it constructs it on the fly.
     * @param {string|string[]} path
     * @param [refCube] Optional cube object to operate on
     */
    resolveGranularity(path: string | string[], refCube?: any): any;
    protected cubeDependenciesProxy(parentIndex: any, cubeName: any): any;
    protected timeDimDependenciesProxy(parentIndex: any): {};
    isCurrentCube(name: any): boolean;
    static isCalculatedMeasureType(type: string): boolean;
    /**
     TODO: support type qualifiers on min and max
     */
    static toMemberDataType(type: string): string;
    static contextSymbolsProxyFrom(symbols: object, allocateParam: (param: unknown) => unknown): object;
}
export {};
//# sourceMappingURL=CubeSymbols.d.ts.map